Object.defineProperty(exports, '__esModule', { value: true });

const browser = require('@sentry/browser');
const core = require('@sentry/core');

// Tree-shakable guard to remove all code related to tracing

/**
 * Initialize the client side of the Sentry Astro SDK.
 *
 * @param options Configuration options for the SDK.
 */
function init(options) {
  const opts = {
    defaultIntegrations: getDefaultIntegrations(options),
    ...options,
  };

  core.applySdkMetadata(opts, 'astro', ['astro', 'browser']);

  return browser.init(opts);
}

function getDefaultIntegrations(options) {
  // This evaluates to true unless __SENTRY_TRACING__ is text-replaced with "false",
  // in which case everything inside will get tree-shaken away
  if (typeof __SENTRY_TRACING__ === 'undefined' || __SENTRY_TRACING__) {
    return [...browser.getDefaultIntegrations(options), browser.browserTracingIntegration()];
  } else {
    return browser.getDefaultIntegrations(options);
  }
}

exports.init = init;
//# sourceMappingURL=sdk.js.map
